@@ -287,6 +287,7 @@ typedef struct
 
   /* Radiation pattern window position and size */
   int
+    rdpattern_is_open,
     rdpattern_x,
     rdpattern_y,
     rdpattern_width,
@@ -303,6 +304,7 @@ typedef struct
 
   /* Frequency plots window state of widgetsposition and size */
   int
+    freqplots_is_open,
     freqplots_x,
     freqplots_y,
     freqplots_width,
@@ -356,6 +358,8 @@ typedef struct
   int opt_write_s1p;
   int opt_write_s2p_max_gain;
   int opt_write_s2p_viewer_gain;
+  int opt_write_rdpat;
+  int opt_write_currents;
 
   /* If for example --write-csv <file> is added to the cmdline then write
    * the file after each frequency iteration */
@@ -363,6 +367,8 @@ typedef struct
   char *filename_s1p;
   char *filename_s2p_max_gain;
   char *filename_s2p_viewer_gain;
+  char *filename_rdpat;
+  char *filename_currents;
 } rc_config_t;
 
 typedef struct {
@@ -1403,7 +1409,9 @@ void Save_FreqPlots_S2P_Viewer_Gain(char *filename);
 void Save_FreqPlots_CSV(char *filename);
 void Save_FreqPlots_Gnuplot_Data(char *filename);
 void Save_RadPattern_Gnuplot_Data(char *filename);
+void Save_RadPattern_CSV(char *filename);
 void Save_Struct_Gnuplot_Data(char *filename);
+void Save_Currents_CSV(char *filename);
 /* ground.c */
 void rom2(double a, double b, _Complex double *sum, double dmin);
 void sflds(double t, _Complex double *e);
