@@ -38,6 +38,8 @@ enum XNEC2C_OPTS {
 	OPT_WRITE_S1P,
 	OPT_WRITE_S2P_MAX_GAIN,
 	OPT_WRITE_S2P_VIEWER_GAIN,
+	OPT_WRITE_RDPAT,
+	OPT_WRITE_CURRENTS,
 
 	OPT_MAX_OPTS
 };
@@ -59,6 +61,8 @@ static struct option long_options[] = {
 		{  "write-s1p",              required_argument,   NULL,  OPT_WRITE_S1P              },
 		{  "write-s2p-max-gain",     required_argument,   NULL,  OPT_WRITE_S2P_MAX_GAIN     },
 		{  "write-s2p-viewer-gain",  required_argument,   NULL,  OPT_WRITE_S2P_VIEWER_GAIN  },
+		{  "write-rdpat",            required_argument,   NULL,  OPT_WRITE_RDPAT            },
+		{  "write-currents",         required_argument,   NULL,  OPT_WRITE_CURRENTS         },
 
 		{  NULL,                     0,                   NULL,  0                          }
 	};
@@ -91,15 +95,6 @@ static gint opt_start_optimizer_thread()
 {
 	GtkWidget *w;
 
-	w = Builder_Get_Object(main_window_builder, "main_freqplots");
-	if (!gtk_check_menu_item_get_active( GTK_CHECK_MENU_ITEM(w)))
-	{
-		Notice(_("Xnec2c Optimize"),
-			_("Frequency plots window is not configured. "
-			"Select your desired graphs and click the triangle \"Play\" button."), GTK_BUTTONS_OK);
-		gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(w), TRUE);
-	}
-
 	w = Builder_Get_Object(main_window_builder, "optimizer_output");
 	gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(w), TRUE);
 
@@ -181,6 +176,7 @@ main (int argc, char *argv[])
 
       case 'd': /* debug */
         rc_config.debug++;
+        rc_config.verbose += 3;
         break;
 
       case 'q': /* quiet */
@@ -240,6 +236,14 @@ main (int argc, char *argv[])
         rc_config.filename_s2p_viewer_gain = optarg;
         break;
 
+      case OPT_WRITE_RDPAT:
+        rc_config.filename_rdpat = optarg;
+        break;
+
+      case OPT_WRITE_CURRENTS:
+        rc_config.filename_currents = optarg;
+        break;
+
       default:
         usage();
         exit(0);
