@@ -29,12 +29,16 @@ int opt_have_files_to_save()
         rc_config.opt_write_s1p ||
         rc_config.opt_write_s2p_max_gain ||
         rc_config.opt_write_s2p_viewer_gain ||
+		rc_config.opt_write_rdpat ||
+		rc_config.opt_write_currents ||
 
 		// Files:
 		rc_config.filename_csv ||
 		rc_config.filename_s1p ||
 		rc_config.filename_s2p_max_gain ||
-		rc_config.filename_s2p_viewer_gain
+		rc_config.filename_s2p_viewer_gain ||
+		rc_config.filename_rdpat ||
+		rc_config.filename_currents
 	);
 }
 
@@ -46,6 +50,7 @@ _Write_Optimizer_Data( void )
   char filename[FILENAME_LEN];
   size_t n = sizeof( filename );
 
+  // from the menu:
   if (rc_config.opt_write_csv)
 	  Save_FreqPlots_CSV(str_append(filename, rc_config.input_file, ".csv", n));
 
@@ -58,6 +63,14 @@ _Write_Optimizer_Data( void )
   if (rc_config.opt_write_s2p_viewer_gain)
 	  Save_FreqPlots_S2P_Viewer_Gain(str_append(filename, rc_config.input_file, "-viewergain.s2p", n));
 
+  if (rc_config.opt_write_rdpat)
+	  Save_RadPattern_CSV(str_append(filename, rc_config.input_file, "-radpattern.csv", n));
+
+  if (rc_config.opt_write_currents)
+	  Save_Currents_CSV(str_append(filename, rc_config.input_file, "-currents.csv", n));
+
+
+  // from the cmdline:
   if (rc_config.filename_csv)
 	  Save_FreqPlots_CSV(rc_config.filename_csv);
 
@@ -70,6 +83,18 @@ _Write_Optimizer_Data( void )
   if (rc_config.filename_s2p_viewer_gain)
 	  Save_FreqPlots_S2P_Viewer_Gain(rc_config.filename_s2p_viewer_gain);
 
+  if (rc_config.filename_rdpat)
+  {
+	pr_debug("saving rdpat: %s\n", rc_config.filename_rdpat);
+	Save_RadPattern_CSV(rc_config.filename_rdpat);
+  }
+
+  if (rc_config.filename_currents)
+  {
+	pr_debug("saving currents: %s\n", rc_config.filename_currents);
+	Save_Currents_CSV(rc_config.filename_currents);
+  }
+
 } // Write_Optimizer_Data()
 
 void Write_Optimizer_Data( void )
@@ -141,15 +166,17 @@ Optimizer_Output( void *arg )
 	// Re-open the inotify handle if the filename changes.  This works
 	// for the first iteration too because prev_input_file is empty:
 	if (strcmp(prev_input_file, rc_config.input_file))
-	{
-	  if (fd > 0)
-		close(fd);
+    {
+      if (fd > 0) close( fd );
 
-	  fd = inotify_open(&pfd);
-	  if (fd < 0)
-		  ClearFlag(OPTIMIZER_OUTPUT);
+      fd = inotify_open( &pfd );
+      if (fd < 0)
+      {
+        ClearFlag( OPTIMIZER_OUTPUT );
+        return( NULL );
+      }
 
-	  strncpy(prev_input_file, rc_config.input_file, sizeof(prev_input_file));
+      Strlcpy(prev_input_file, rc_config.input_file, sizeof(prev_input_file));
 	}
 
     // Exit thread if optimizer output has been cancelled
@@ -240,7 +267,7 @@ Optimizer_Output( void *arg )
   } // while( TRUE )
 
   /* Close inotify file descriptor. */
-  close( fd );
+  if( fd >= 0) close( fd );
   return( NULL );
 } // Optimizer_Output()
 
