@@ -247,8 +247,8 @@ void draw_text(cairo_t *cr, GtkWidget *widget,
 Display_Frequency_Data( void )
 {
   int fstep;
-  double vswr;
-  char txt[12];
+  double vswr, zreal, zimag;
+  char txt[16];
 
   measurement_t meas;
 
@@ -266,31 +266,40 @@ Display_Frequency_Data( void )
   meas_calc(&meas, fstep);
 
   /* Display max gain */
-  snprintf( txt, 7, "%5.1f", meas.gain_max );
+  snprintf( txt, sizeof(txt)-1, "%.2f", meas.gain_max );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
           freqplots_window_builder, "freqplots_maxgain_entry")), txt );
 
   /* Display frequency */
-  snprintf( txt, 11, "%9.3f", (double)calc_data.freq_mhz );
+  snprintf( txt, sizeof(txt)-1, "%.3f", (double)calc_data.freq_mhz );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
           freqplots_window_builder, "freqplots_fmhz_entry")), txt );
 
+  // Prevent UI overflows that cause beeps:
   vswr = meas.vswr;
   if( vswr > 999.0 )
     vswr = 999.0;
 
+  zreal = meas.zreal;
+  if (zreal > 1e6)
+	  zreal = 999999;
+
+  zimag = meas.zimag;
+  if (zimag > 1e6)
+	  zimag = 999999;
+
   /* Display VSWR */
-  snprintf( txt, 7, "%5.1f", vswr );
+  snprintf( txt, sizeof(txt)-1, "%.2f", vswr );
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
           freqplots_window_builder, "freqplots_vswr_entry")), txt );
 
   /* Display Z real */
-  snprintf( txt, 7, "%5.1f", (double)meas.zreal);
+  snprintf( txt, sizeof(txt)-1, "%.1f", zreal);
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
           freqplots_window_builder, "freqplots_zreal_entry")), txt );
 
   /* Display Z imaginary */
-  snprintf( txt, 7, "%5.1f", (double)meas.zimag);
+  snprintf( txt, sizeof(txt)-1, "%.1f", zimag);
   gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
           freqplots_window_builder, "freqplots_zimag_entry")), txt );
 
@@ -408,6 +417,7 @@ Fit_to_Scale2( double *max1, double *min1,
   // Do nothing in these cases 
   if( *max1 <= *min1 ) return;
   if( *max2 == *min2 ) return;
+  if( *nval < 3 ) return;
 
   /* Provide a made-up range if max = min */
   if( *max1 == *min1 )
@@ -637,8 +647,9 @@ Plot_Vertical_Scale(
   double vstep = 1.0;
   char value[16], format[16];
 
-  /* Abort if not enough values to plot */
-  if( nval <= 1 ) return;
+  /* only plot min/max if there are not enough values to plot */
+  if( nval <= 1 )
+    nval = 2;
 
   /* Calculate step between scale values */
   vstep = (max-min) / (double)(nval-1);
@@ -771,7 +782,7 @@ Draw_Graph(
   double ra, rb;
   int idx;
   GdkPoint *points = NULL;
-  char s[20];
+  char s[23];
 
   /* Cairo context */
   cairo_set_source_rgb( cr, red, grn, blu );
@@ -1293,8 +1304,7 @@ _Plot_Frequency_Data( cairo_t *cr )
 {
   /* Abort plotting if main window is to be closed
    * or when plots drawing area not available */
-  if( isFlagSet(MAIN_QUIT) ||
-      isFlagClear(PLOT_ENABLED) ||
+  if( isFlagClear(PLOT_ENABLED) ||
       isFlagClear(ENABLE_EXCITN) )
     return;
 
@@ -1585,16 +1595,13 @@ void Plot_Frequency_Data( cairo_t *cr )
   void
 Plots_Window_Killed( void )
 {
-  rc_config.freqplots_width  = 0;
-  rc_config.freqplots_height = 0;
-
   // Reset this for next time otherwise width_available rescales in Plot_Graph will not work.
   prev_width_available = 0;
   prev_ngraphs = 0;
 
   if( isFlagSet(PLOT_ENABLED) )
   {
-    ClearFlag( PLOT_FLAGS );
+    ClearFlag( PLOT_ENABLED );
     freqplots_drawingarea = NULL;
     g_object_unref( freqplots_window_builder );
     freqplots_window_builder = NULL;
@@ -1804,15 +1811,15 @@ _Set_Frequency_On_Click( GdkEvent *e)
 
   if (set_fmhz)
   {
-	  /* Round frequency to nearest 1 kHz */
-	  int ifmhz = ( fmhz * 1e6 + 0.5 );
+	  /* Round frequency to nearest 1 Hz */
+	  uint64_t ifmhz = ( fmhz * 1e6 + 0.5 );
 	  fmhz = ifmhz / 1e6;
 
 	  /* Save frequency for later use when the graph plots after the NEC2 run */
 	  calc_data.fmhz_save = fmhz;
 
 	  /* Set frequency spinbuttons on new freq */
-	  if( fmhz != calc_data.freq_mhz )
+	  if( isFlagClear(FREQ_LOOP_RUNNING) && fmhz != calc_data.freq_mhz )
 	  {
 		gtk_spin_button_set_value( mainwin_frequency, fmhz );
 		if( isFlagSet(DRAW_ENABLED) )
