@@ -40,7 +40,7 @@ void _print_backtrace(char **strings);
   void
 usage(void)
 {
-  fprintf(stderr, "Usage: xnec2c [options] [<input-file-name>]\n"
+  fprintf(stdout, "Usage: xnec2c [options] [<input-file-name>]\n"
 		"  -i|--input <input-file-name>\n"
 		"  -j|--jobs  <number of processors in SMP machine> (-j0 disables forking)\n"
 		"  -b|--batch:        enable batch mode, exit after the frequency loop runs\n"
@@ -57,10 +57,12 @@ usage(void)
 		"filenames to write without --batch mode then enable the File->Optimizer\n"
 		"Settings or the files you specify on the command line will not be written.\n"
 		"\n"
-		"  --write-csv <filename>\n"
-		"  --write-s1p <filename>\n"
-		"  --write-s2p-max-gain <filename>\n"
-		"  --write-s2p-viewer-gain <filename>\n");
+		"  --write-csv             <filename>  - write CSV file of measurements\n"
+		"  --write-s1p             <filename>  - write S1P file of S-parameters\n"
+		"  --write-s2p-max-gain    <filename>  - write S2P file, port-2 is max-gain\n"
+		"  --write-s2p-viewer-gain <filename>  - write S2P file, port-2 is viewer-gain\n"
+		"  --write-rdpat           <filename>  - write CSV of the radiation pattern\n"
+		"  --write-currents        <filename>  - write CSV of currents and charges\n");
 
 } /* end of usage() */
 
@@ -129,7 +131,7 @@ Stop( char *mesg, int err )
   while( isFlagSet(ERROR_CONDX) )
   {
 	// We are out of gtk_main() so iterate manually:
-	while( g_main_context_iteration(NULL, FALSE) );
+	while( g_main_context_iteration(NULL, FALSE) ) {}
 
     if( isFlagSet(MAIN_QUIT) ) exit(-1);
 
@@ -163,7 +165,7 @@ Nec2_Save_Warn( const gchar *mesg )
     while( isFlagSet(ERROR_CONDX) )
     {
       // We are out of gtk_main() so iterate manually:
-      while( g_main_context_iteration(NULL, FALSE) );
+      while( g_main_context_iteration(NULL, FALSE) ) {}
 
       if( isFlagSet(MAIN_QUIT) ) exit(-1);
 
@@ -671,8 +673,11 @@ typedef struct
 	GSourceOnceFunc function;
 	gpointer data;
 	GMutex lock;
+	GCond cond;
 	int is_locked;
 	char **backtrace;
+
+	volatile int done;
 } g_idle_add_data_t;
 
 
@@ -688,7 +693,7 @@ int _callback_g_idle_add_once(g_idle_add_data_t *cbdata)
 	if (cbdata->is_locked)
 	{
 		// Wait for GTK
-		while (g_main_context_iteration(NULL, FALSE));
+		while (g_main_context_iteration(NULL, FALSE)) {}
 		
 		if (cbdata->backtrace != NULL)
 		{
@@ -696,6 +701,10 @@ int _callback_g_idle_add_once(g_idle_add_data_t *cbdata)
 			cbdata->backtrace = NULL;
 		}
 
+		// Signal the waiting thread:
+		g_mutex_lock(&cbdata->lock);
+		cbdata->done = 1;
+		g_cond_signal(&cbdata->cond);
 		g_mutex_unlock(&cbdata->lock);
 	}
 	else
@@ -725,27 +734,35 @@ guint _g_idle_add_once(GSourceOnceFunc function, gpointer data, int lock)
 	if (rc_config.disable_pthread_freqloop)
 		lock = 0;
 
-	g_mutex_init(&cbdata->lock);
+	if (lock)
+	{
+		g_mutex_init(&cbdata->lock);
+		g_cond_init(&cbdata->cond);
+	}
 
 	cbdata->function = function;
 	cbdata->data = data;
 	cbdata->is_locked = lock;
+	cbdata->done = 0;
 
 	cbdata->backtrace = NULL;
 
 	// Debug async call backtraces if you need it, but be aware that _get_backtrace() is slow.
 	//cbdata->backtrace = _get_backtrace();
 
-	if (lock)
-		g_mutex_lock(&cbdata->lock);
-
 	ret = g_idle_add((GSourceFunc)_callback_g_idle_add_once, cbdata);
 
 	// Wait for the lock to release and free it.
 	if (lock)
 	{
 		g_mutex_lock(&cbdata->lock);
+		while (!cbdata->done)
+			g_cond_wait(&cbdata->cond, &cbdata->lock);
 		g_mutex_unlock(&cbdata->lock);
+
+		g_mutex_clear(&cbdata->lock);
+		g_cond_clear(&cbdata->cond);
+
 		free_ptr((void**)&cbdata);
 	}
 
