@@ -499,8 +499,8 @@ static gboolean retval; /* Function's return value */
 int update_freqplots_fmhz_entry(gpointer p)
 {
     /* Display current frequency in plots entry */
-    char txt[10];
-    snprintf( txt, sizeof(txt), "%9.3f", calc_data.freq_mhz );
+    char txt[16];
+    snprintf( txt, sizeof(txt)-1, "%.3f", calc_data.freq_mhz );
     gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
             freqplots_window_builder, "freqplots_fmhz_entry")), txt );
 
@@ -808,7 +808,7 @@ gboolean Frequency_Loop( gpointer udata )
 		  retval = FALSE;
 		  if (num_busy_procs != 0)
 		  {
-			  BUG("Frequency_Loop is done with all steps but num_busy_procs=%d (calc_data.freq_step=%d calc_data.steps_total=%d)?\n",
+			  pr_debug("Frequency_Loop is done with all steps but num_busy_procs=%d (calc_data.freq_step=%d calc_data.steps_total=%d)?\n",
                               num_busy_procs, calc_data.freq_step,
                               calc_data.steps_total);
 				for( job_num = 0; job_num < calc_data.num_jobs; job_num++ )
@@ -950,6 +950,9 @@ void *Frequency_Loop_Thread(void *p)
 
 	ClearFlag(FREQ_LOOP_RUNNING);
 
+	if (isFlagSet(FREQ_LOOP_STOP))
+		return NULL;
+
 	// Exit if in batch mode
 	if (rc_config.batch_mode)
 	{
@@ -1039,6 +1042,7 @@ Stop_Frequency_Loop( void )
 {
   // Clearing this flag will cause the Frequency_Loop pthread to exit when it is done:
   ClearFlag( FREQ_LOOP_RUNNING );
+  SetFlag(FREQ_LOOP_STOP);
 
   if (!rc_config.disable_pthread_freqloop)
   {
@@ -1048,6 +1052,11 @@ Stop_Frequency_Loop( void )
 		  pthread_join(*pth_freq_loop, NULL);
 		  free_ptr((void**)&pth_freq_loop);
 	  }
+
+	  // Flush any pending GTK events. This is critical because any pending
+	  // events that may work upon GtkWidget's that change (or close) upon exit
+	  // from this function will fail.
+	  while( g_main_context_iteration(NULL, FALSE) ) {}
   }
   else if( floop_tag > 0 )
   {
